Exclude session information from Redfish enumeration

Change-Id: I7dffc368916e01103c0b4fdc407eda9d678ad50d
Signed-off-by: Anusha Dathatri <adathatr@in.ibm.com>
diff --git a/lib/bmc_redfish_utils.py b/lib/bmc_redfish_utils.py
index 064b967..872a998 100644
--- a/lib/bmc_redfish_utils.py
+++ b/lib/bmc_redfish_utils.py
@@ -202,9 +202,10 @@
 
         while resources_to_be_enumerated:
             for resource in resources_to_be_enumerated:
                 # JsonSchemas data are not required in enumeration.
                 # Example: '/redfish/v1/JsonSchemas/' and sub resources.
-                if 'JsonSchemas' in resource:
+                #          '/redfish/v1/SessionService'
+                if ('JsonSchemas' in resource) or ('SessionService' in resource):
                     continue
 
                 self._rest_response_ = \
@@ -202,9 +202,10 @@
         while resources_to_be_enumerated:
             for resource in resources_to_be_enumerated:
-                # JsonSchemas data are not required in enumeration.
+                # JsonSchemas and SessionService data are not required in enumeration.
                 # Example: '/redfish/v1/JsonSchemas/' and sub resources.